@@ -1,8 +1,8 @@
-# $Header: /usr/local/CVS/Perl-Metrics-Simple/lib/Perl/Metrics/Simple/Analysis/File.pm,v 1.15 2007/12/30 21:37:31 matisse Exp $
-# $Revision: 1.15 $
+# $Header: /usr/local/CVS/Perl-Metrics-Simple/lib/Perl/Metrics/Simple/Analysis/File.pm,v 1.18 2008/07/19 22:07:06 matisse Exp $
+# $Revision: 1.18 $
 # $Author: matisse $
 # $Source: /usr/local/CVS/Perl-Metrics-Simple/lib/Perl/Metrics/Simple/Analysis/File.pm,v $
-# $Date: 2007/12/30 21:37:31 $
+# $Date: 2008/07/19 22:07:06 $
 ###############################################################################
 
 package Perl::Metrics::Simple::Analysis::File;
@@ -14,17 +14,19 @@ use Data::Dumper;
 use English qw(-no_match_vars);
 use Perl::Metrics::Simple::Analysis;
 use PPI;
+use PPI::Document;
 use Readonly;
 
-our $VERSION = '0.1';
+our $VERSION = '0.11';
 
-Readonly::Scalar my $ALL_NEWLINES_REGEX => qr/ ( \n ) /xm;
-Readonly::Array our @LOGIC_OPERATORS    =>
-  qw( ! && || ||= &&= or and xor not ? <<= >>= );
+Readonly::Scalar my $ALL_NEWLINES_REGEX =>
+    qr/ ( \Q$INPUT_RECORD_SEPARATOR\E ) /xm;
+Readonly::Array our @LOGIC_OPERATORS =>
+    qw( ! && || ||= &&= or and xor not ? <<= >>= );
 Readonly::Hash our %LOGIC_OPERATORS => hashify(@LOGIC_OPERATORS);
 
 Readonly::Array our @LOGIC_KEYWORDS =>
-  qw( for foreach goto if else elsif last next unless until while );
+    qw( for foreach goto if else elsif last next unless until while );
 Readonly::Hash our %LOGIC_KEYWORDS => hashify(@LOGIC_KEYWORDS);
 
 # Private instance variables:
@@ -37,7 +39,7 @@ my %Lines      = ();
 sub new {
     my ( $class, %parameters ) = @_;
     my $self = {};
-    bless $self, ref $class || $class;
+    bless $self, $class;
     $self->_init(%parameters);
     return $self;
 }
@@ -49,10 +51,10 @@ sub _init {
     my $path = $self->path;
 
     if ( !-r $path ) {
-        confess "Path '$path' is missing or not readable!";
+        Carp::confess "Path '$path' is missing or not readable!";
     }
-
     my $document = _make_pruned_document($path);
+
     if ( !defined $document ) {
         cluck "Could not make a PPI document from '$path'";
         return;
@@ -62,10 +64,10 @@ sub _init {
 
     my @sub_analysis = ();
     my $sub_elements = $document->find('PPI::Statement::Sub');
-    @sub_analysis = @{ $self->_iterate_over_subs( $sub_elements ) };
+    @sub_analysis = @{ $self->_iterate_over_subs($sub_elements) };
 
-    $Main_Stats{$self} =
-      $self->analyze_main( $document, $sub_elements, \@sub_analysis );
+    $Main_Stats{$self}
+        = $self->analyze_main( $document, $sub_elements, \@sub_analysis );
     $Subs{$self}     = \@sub_analysis;
     $Packages{$self} = $packages;
     $Lines{$self}    = $self->get_node_length($document);
@@ -73,14 +75,26 @@ sub _init {
     return $self;
 }
 
-
 sub _make_pruned_document {
     my $path = shift;
-    my $document = PPI::Document->new( $path);
-    $document= _prune_comments_and_pod($document);
+    my $document;
+    if ( -s $path ) {
+        $document = PPI::Document->new($path);
+    }
+    else {
+
+        # The file is empty. Create a PPI document with a single whitespace
+        # chararacter. This makes sure that the PPI tokens() method
+        # returns something, so we avoid a warning from
+        # PPI::Document::index_locations() which expects tokens() to return
+        # something other than undef.
+        my $one_whitespace_character = q{ };
+        $document = PPI::Document->new( \$one_whitespace_character );
+    }
+    $document = _prune_non_code_lines($document);
     $document->index_locations();
     $document->readonly(1);
-    return $document
+    return $document;
 }
 
 sub all_counts {
@@ -101,6 +115,10 @@ sub analyze_main {
     my $sub_elements = shift;
     my $sub_analysis = shift;
 
+    if ( !$document->isa('PPI::Document') ) {
+        Carp::confess('Did not supply a PPI::Document');
+    }
+
     my $lines = $self->get_node_length($document);
     foreach my $sub ( @{$sub_analysis} ) {
         $lines -= $sub->{lines};
@@ -119,24 +137,26 @@ sub analyze_main {
 
 sub get_node_length {
     my ( $self, $node ) = @_;
-    eval {
-        $node = _prune_comments_and_pod($node);
-    };
-    return 0 if ( !defined $node);
+    eval { $node = _prune_non_code_lines($node); };
+    return 0 if ( !defined $node );
     my $string = $node->content;
-    return 0 if ( ! length $string );
-    $string =~ s/ \s+ \n /\n/msxg;
-    $string =~ s/ \A \s+ //msx;
+    return 0 if ( !length $string );
+
+    # Replace whitespace-newline with newline
+    $string =~ s/ \s+ \Q$INPUT_RECORD_SEPARATOR\E /$INPUT_RECORD_SEPARATOR/mxg;
+    $string =~ s/\Q$INPUT_RECORD_SEPARATOR\E /$INPUT_RECORD_SEPARATOR/mxg;
+    $string =~ s/ \A \s+ //msx;    # Remove leading whitespace
     my @newlines = ( $string =~ /$ALL_NEWLINES_REGEX/mxg );
     my $line_count = scalar @newlines;
 
-    # if the string is not empty and the last character is not a newline then add 1
+ # if the string is not empty and the last character is not a newline then add 1
     if ( length $string ) {
         my $last_char = substr $string, -1, 1;
-        if ( $last_char ne "\n" ) {
+        if ( $last_char ne "$INPUT_RECORD_SEPARATOR" ) {
             $line_count++;
         }
     }
+
     return $line_count;
 }
 
@@ -166,15 +186,15 @@ sub lines {
 }
 
 sub measure_complexity {
-    my $self  = shift;
-    my $elem  = shift;
-    
+    my $self = shift;
+    my $elem = shift;
+
     my $complexity_count = 0;
     if ( $self->get_node_length($elem) == 0 ) {
         return $complexity_count;
     }
 
-    if ( $elem ) {
+    if ($elem) {
         $complexity_count++;
     }
 
@@ -186,7 +206,8 @@ sub measure_complexity {
     # Count up all the logic operators
     my $operators_ref = $elem->find('PPI::Token::Operator');
     if ($operators_ref) {
-        $complexity_count += grep { exists $LOGIC_OPERATORS{$_} } @{$operators_ref};
+        $complexity_count
+            += grep { exists $LOGIC_OPERATORS{$_} } @{$operators_ref};
     }
     return $complexity_count;
 }
@@ -198,7 +219,7 @@ sub _get_packages {
     my $found_packages  = $document->find('PPI::Statement::Package');
 
     return \@unique_packages
-      if (
+        if (
         !Perl::Metrics::Simple::Analysis::is_ref( $found_packages, 'ARRAY' ) );
 
     my %seen_packages = ();
@@ -217,19 +238,19 @@ sub _iterate_over_subs {
     my $found_subs = shift;
 
     return []
-      if ( !Perl::Metrics::Simple::Analysis::is_ref( $found_subs, 'ARRAY' ) );
+        if ( !Perl::Metrics::Simple::Analysis::is_ref( $found_subs, 'ARRAY' ) );
 
     my @subs = ();
 
     foreach my $sub ( @{$found_subs} ) {
         my $sub_length = $self->get_node_length($sub);
         push @subs,
-          {
+            {
             path              => $self->path,
             name              => $sub->name,
             lines             => $sub_length,
             mccabe_complexity => $self->measure_complexity($sub),
-          };
+            };
     }
     return \@subs;
 }
@@ -251,11 +272,11 @@ sub is_hash_key {
     my $is_hash_key = eval {
         my $parent      = $ppi_elem->parent();
         my $grandparent = $parent->parent();
-        if ($grandparent->isa('PPI::Structure::Subscript') ) {
+        if ( $grandparent->isa('PPI::Structure::Subscript') ) {
             return 1;
         }
         my $sib = $ppi_elem->snext_sibling();
-        if ($sib->isa('PPI::Token::Operator') && $sib eq '=>' ) {
+        if ( $sib->isa('PPI::Token::Operator') && $sib eq '=>' ) {
             return 1;
         }
         return;
@@ -264,18 +285,20 @@ sub is_hash_key {
     return $is_hash_key;
 }
 
-sub _prune_comments_and_pod {
+sub _prune_non_code_lines {
     my $document = shift;
-
-    $document->prune('PPI::Token::Comment','PPI::Token::Pod',);
+    if ( !defined $document ) {
+        Carp::confess('Did not supply a document!');
+    }
+    $document->prune('PPI::Token::Comment');
+    $document->prune('PPI::Token::Pod');
+    $document->prune('PPI::Token::End');
 
     return $document;
 }
 
 1;
 
-
-
 __END__
 
 =head1 NAME
